OpenGlWallpaperRequestData class

Parameters for applying a shader-based OpenGL live wallpaper.

Constructors

OpenGlWallpaperRequestData({String? fragmentShader, List<WallpaperSourceData?>? textures, WallpaperTargetData? target, int? frameRate})

Properties

fragmentShader ↔ String?
getter/setter pair
frameRate ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ WallpaperTargetData?
getter/setter pair
textures ↔ List<WallpaperSourceData?>?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → OpenGlWallpaperRequestData