OperationResultData class

A truthful, structured result from the host platform.

Constructors

OperationResultData({OperationStatusData? status, WallpaperTargetData? requestedTarget, TargetResultData? home, TargetResultData? lock, String? errorCode, String? errorMessage, String? errorDetails, bool? fallbackUsed, WallpaperApplyStrategyData? fallbackStrategy})

Properties

errorCode String?
getter/setter pair
errorDetails String?
getter/setter pair
errorMessage String?
getter/setter pair
fallbackStrategy WallpaperApplyStrategyData?
getter/setter pair
fallbackUsed bool?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
home TargetResultData?
getter/setter pair
lock TargetResultData?
getter/setter pair
requestedTarget WallpaperTargetData?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status OperationStatusData?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) OperationResultData