TargetResultData class

Result details for one target display.

Constructors

TargetResultData({TargetStatusData? status, String? errorCode, String? errorMessage, String? errorDetails})

Properties

errorCode String?
getter/setter pair
errorDetails String?
getter/setter pair
errorMessage String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TargetStatusData?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) TargetResultData