WallpaperApi class
Constructors
WallpaperApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for WallpaperApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
checkMaterialYouSupport ()
→ Future <MaterialYouSupportData >
getPlatformVersion ()
→ Future <String >
getWallpaperRotationStatus ()
→ Future <WallpaperRotationStatusData >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWallpaperChooser ()
→ Future <bool >
rotateWallpaperNow ()
→ Future <bool >
setBothWallpaperFromFile (String filePath , bool goToHome )
→ Future <bool >
setBothWallpaperFromUrl (String url , bool goToHome )
→ Future <bool >
setHomeWallpaperFromFile (String filePath , bool goToHome )
→ Future <bool >
setHomeWallpaperFromUrl (String url , bool goToHome )
→ Future <bool >
setLiveWallpaper (String filePath , bool goToHome )
→ Future <bool >
setLockWallpaperFromFile (String filePath , bool goToHome )
→ Future <bool >
setLockWallpaperFromUrl (String url , bool goToHome )
→ Future <bool >
setMaterialYouWallpaper (String url , bool goToHome , bool enableEffects )
→ Future <bool >
setWallpaper (String url , bool goToHome )
→ Future <bool >
setWallpaperFromFile (String filePath , bool goToHome )
→ Future <bool >
startWallpaperRotation (WallpaperRotationConfigData config )
→ Future <bool >
stopWallpaperRotation ()
→ Future <bool >
toString ()
→ String
A string representation of this object.
inherited