WallpaperRotationStatusData class

Constructors

WallpaperRotationStatusData({bool? isRunning, int? nextRunEpochMs, int? currentIndex, int? cachedCount, int? totalCount, String? lastError, int? effectiveIntervalMinutes})

Properties

cachedCount int?
getter/setter pair
currentIndex int?
getter/setter pair
effectiveIntervalMinutes int?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isRunning bool?
getter/setter pair
lastError String?
getter/setter pair
nextRunEpochMs int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) WallpaperRotationStatusData