WallpaperSourceData class
A static, content-provider, or in-memory wallpaper source.
Constructors
- WallpaperSourceData({WallpaperSourceKindData? kind, String? url, String? filePath, String? contentUri, Uint8List? bytes})
Properties
- bytes ↔ Uint8List?
-
getter/setter pair
- contentUri ↔ String?
-
getter/setter pair
- filePath ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- kind ↔ WallpaperSourceKindData?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url ↔ String?
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → WallpaperSourceData