StaticWallpaperRequestData class
Parameters for an image wallpaper operation.
Constructors
- StaticWallpaperRequestData({WallpaperSourceData? source, WallpaperTargetData? target, WallpaperScaleModeData? scaleMode, WallpaperApplyStrategyData? strategy, bool? goToHome})
Properties
- goToHome ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleMode ↔ WallpaperScaleModeData?
-
getter/setter pair
- source ↔ WallpaperSourceData?
-
getter/setter pair
- strategy ↔ WallpaperApplyStrategyData?
-
getter/setter pair
- target ↔ WallpaperTargetData?
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → StaticWallpaperRequestData