WallpaperRotationConfigData class

Constructors

WallpaperRotationConfigData({List<RotationSourceData?>? sources, WallpaperTargetData? target, int? intervalMinutes, bool? enableIntervalTrigger, bool? enableChargingTrigger, bool? enableTimeOfDayTrigger, int? activeHoursStart, int? activeHoursEnd, RotationOrderData? orderType})

Properties

activeHoursEnd ↔ int?
getter/setter pair
activeHoursStart ↔ int?
getter/setter pair
enableChargingTrigger ↔ bool?
getter/setter pair
enableIntervalTrigger ↔ bool?
getter/setter pair
enableTimeOfDayTrigger ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
intervalMinutes ↔ int?
getter/setter pair
orderType ↔ RotationOrderData?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources ↔ List<RotationSourceData?>?
getter/setter pair
target ↔ WallpaperTargetData?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → WallpaperRotationConfigData